==> haskell-crypton-x509-validation-1.6.14-52-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509-validation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-x509-validation
version:              1.6.14
visibility:           public
id:                   crypton-x509-validation-1.6.14-IqF5oYQxQOBIws7InkBAZb
key:                  crypton-x509-validation-1.6.14-IqF5oYQxQOBIws7InkBAZb
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             X.509 Certificate and CRL validation
description:          X.509 Certificate and CRL validation. please see README
category:             Data
abi:                  c711f9c6a50ebf3fc086bf9a0e4bc1e8
exposed:              True
exposed-modules:      Data.X509.Validation
hidden-modules:
    Data.X509.Validation.Signature Data.X509.Validation.Fingerprint
    Data.X509.Validation.Cache Data.X509.Validation.Types

import-dirs:
    /usr/lib/ghc-9.6.6/site-local/crypton-x509-validation-1.6.14

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/crypton-x509-validation-1.6.14

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/crypton-x509-validation-1.6.14

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509-validation
hs-libraries:         HScrypton-x509-validation-1.6.14-IqF5oYQxQOBIws7InkBAZb
depends:
    asn1-encoding-0.9.6-f2brNU34Hf3xe9CSPQRHn
    asn1-types-0.3.4-463kziEGjPc1qXS6uMhRJO base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    crypton-1.0.4-11gen3PFWz54w2m32bVEwY
    crypton-x509-1.7.7-36kCqNSNK3p1rkA4mLjsoT
    crypton-x509-store-1.6.12-8u0cMDz1Er0H0crmNaS9QT
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    hourglass-0.2.12-9RVtelOw0wXG6YiBQxfho6
    iproute-1.7.15-8MQv32arzXu8ybbx4AUApr
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5 mtl-2.3.1
    pem-0.2.4-BtvjegbjHoRAGAf9oBrW3C

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509-validation/html/crypton-x509-validation.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509-validation/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypton-x509-validation-1.6.14-53-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509-validation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-x509-validation
version:              1.6.14
visibility:           public
id:                   crypton-x509-validation-1.6.14-CJfTr1zl9LJIXFreOKwOh2
key:                  crypton-x509-validation-1.6.14-CJfTr1zl9LJIXFreOKwOh2
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             X.509 Certificate and CRL validation
description:          X.509 Certificate and CRL validation. please see README
category:             Data
abi:                  fc2b952379d9ae5031233d2ba7c893ae
exposed:              True
exposed-modules:      Data.X509.Validation
hidden-modules:
    Data.X509.Validation.Signature Data.X509.Validation.Fingerprint
    Data.X509.Validation.Cache Data.X509.Validation.Types

import-dirs:
    /usr/lib/ghc-9.6.6/site-local/crypton-x509-validation-1.6.14

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/crypton-x509-validation-1.6.14

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/crypton-x509-validation-1.6.14

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509-validation
hs-libraries:         HScrypton-x509-validation-1.6.14-CJfTr1zl9LJIXFreOKwOh2
depends:
    asn1-encoding-0.9.6-4rkJHO0pUeFCGFdsLyrUdt
    asn1-types-0.3.4-3PelmjEeZz36Y9JkroV62e base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    crypton-1.0.4-8iIZddQo7Y8B1JLRcnCUbI
    crypton-x509-1.7.7-6vuhyPxGrsd7bUuwSROapz
    crypton-x509-store-1.6.12-Kpp5jEsJnJk1mLM8EMOCOC
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    hourglass-0.2.12-91uaLvWJDdFIwz6ObSsY6A
    iproute-1.7.15-G8PIBt0bMmIHonL1qb456T
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5 mtl-2.3.1
    pem-0.2.4-G3GIG2bUe0L9P6z0Mw3OGw

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509-validation/html/crypton-x509-validation.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509-validation/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
